isDoNotSell static method
Returns whether the user has opted out of interest-based advertising.
Implementation
static Future<bool?> isDoNotSell() {
return _methodChannel.invokeMethod('isDoNotSell');
}
Returns whether the user has opted out of interest-based advertising.
static Future<bool?> isDoNotSell() {
return _methodChannel.invokeMethod('isDoNotSell');
}