setMuted static method
Sets whether to begin video ads in a muted state or not.
Note: Not all networks support this setting.
Implementation
static void setMuted(bool muted) {
_methodChannel.invokeMethod('setMuted', {
'value': muted,
});
}
Sets whether to begin video ads in a muted state or not.
Note: Not all networks support this setting.
static void setMuted(bool muted) {
_methodChannel.invokeMethod('setMuted', {
'value': muted,
});
}