MaxAd class

Represents an ad that has been served by AppLovin MAX.

Properties

adFormat → String
The ad format of this ad.
final
adUnitId → String
The ad unit ID for which this ad was loaded.
final
adViewId → AdViewId?
The unique ID of the platform widget AdView.
final
creativeId → String
The creative ID tied to the ad, if any. You can report creative issues to the corresponding ad network using this ID.
final
dspName → String
The DSP that served the ad when using AppLovin Exchange.
final
hashCode → int
The hash code for this object.
no setterinherited
latencyMillis → int
The latency of the mediation ad load request in milliseconds.
final
nativeAd → MaxNativeAd?
An instance of MaxNativeAd, available only for native ads.
final
networkName → String
The ad network from which this ad was loaded.
final
networkPlacement → String
The ad network placement for which this ad was loaded.
final
placement → String
The custom placement name assigned during integration.
final
revenue → double
The revenue amount for this ad. Returns 0 if unavailable.
final
revenuePrecision → String
The precision of the revenue value for this ad.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size?
The size of the AdView format ad.
final
waterfall → MaxAdWaterfallInfo
The underlying waterfall of ad responses.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited