height property

double? height
final

The ad height. If null, a default is computed based on adFormat and layout constraints.

If adaptive_banner is enabled, the height is calculated using AppLovinMAX.getAdaptiveBannerHeightForWidth.

Implementation

final double? height;