MaxAdWaterfallInfo class

Represents an ad waterfall in AppLovin's MAX mediation.

Properties

hashCode → int
The hash code for this object.
no setterinherited
latencyMillis → int
The total latency in milliseconds for this waterfall to finish processing.
final
name → String
The ad waterfall name.
final
networkResponses → List<MaxNetworkResponse>
The list of MaxNetworkResponse info objects relating to each ad in the waterfall, ordered by their position.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
testName → String
The ad waterfall test name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited