MaxConfiguration class

Encapsulates various flags related to the SDK configuration.

Properties

appTrackingStatus → AppTrackingStatus?
Indicates whether the user has authorized tracking via app-related data.
final
consentFlowUserGeography → ConsentFlowUserGeography?
The user's geography used to determine the type of consent flow shown to the user.
final
countryCode → String?
The country code for this user.
final
hashCode → int
The hash code for this object.
no setterinherited
isTestModeEnabled → bool?
Whether or not test mode is enabled for this session.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited