MaxError class

Encapsulates various data for MAX load and display errors.

Properties

adViewId → AdViewId?
The unique ID of the platform widget AdView.
final
code → ErrorCode
The error code that describes the failure.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
The error message for the error.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
waterfall → MaxAdWaterfallInfo?
The ad waterfall that resulted in this error, if available.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited