MaxMediatedNetworkInfo class

Represents information for a mediated network.

Properties

adapterClassName → String
The class name of the adapter for the mediated network.
final
adapterVersion → String
The version of the adapter for the mediated network.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the network being mediated.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdkVersion → String
The version of the mediated network’s SDK.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited