MaxNativeAd class

Represents a native ad.

Properties

advertiser → String?
The native ad advertiser text.
final
body → String?
The native ad body text.
final
callToAction → String?
The native ad CTA button text.
final
hashCode → int
The hash code for this object.
no setterinherited
isIconImageAvailable → bool
Indicates whether an icon image is available.
final
isMediaViewAvailable → bool
Indicates whether a media view is available.
final
isOptionsViewAvailable → bool
Indicates whether an options view is available.
final
mediaContentAspectRatio → double?
The aspect ratio for the media view if provided by the network.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
starRating → double?
The star rating for the native ad, if available. Ranges from 0.0 to 5.0.
final
title → String?
The native ad title text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited