latencyMillis property

int latencyMillis
final

The amount of time the network took to load (either successfully or not) an ad, in seconds. If an attempt to load an ad has not been made (i.e. the loadState is AdLoadState.adLoadNotAttempted), the value will be -1.

Implementation

final int latencyMillis;