BaseLoad class abstract

Implementers

Constructors

BaseLoad()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

load(MtadKey key, Map<String, dynamic> itemData, String pid) → Future
loadId(String id) → dynamic
loadSus(Cache cache, Map<String, dynamic> itemData, String pid) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited